@@ -2,7 +2,7 @@ from typing import Optional
 
 import typer
 
-from . import cluster, packages, projects, sources, tasks
+from . import cluster, packages, projects, sources, tasks, recipes, gcp
 from .about import __version__
 from .utils import get_fresh_api_token, get_fresh_id_token, printer, set_cli_host
 
@@ -12,6 +12,8 @@ cli.add_typer(sources.app, name="sources")
 cli.add_typer(packages.app, name="packages")
 cli.add_typer(projects.app, name="projects")
 cli.add_typer(tasks.app, name="tasks")
+cli.add_typer(recipes.app, name="recipes")
+cli.add_typer(gcp.app, name="gcp")
 
 
 def print_version(ctx: typer.Context, param, value: bool) -> None:
