@@ -457,15 +457,15 @@ broker_meta_response = {
     },
     "models": {
         "english_small": {
-            "name": "/usr/local/data/spacy-models/2.2.5/en_core_web_sm",
+            "name": "/usr/local/data/spacy-models/2.3.0/en_core_web_sm",
             "title": "English (Small)",
         },
         "english_medium": {
-            "name": "/usr/local/data/spacy-models/2.2.5/en_core_web_md",
+            "name": "/usr/local/data/spacy-models/2.3.0/en_core_web_md",
             "title": "English (Medium)",
         },
         "english_large": {
-            "name": "/usr/local/data/spacy-models/2.2.5/en_core_web_lg",
+            "name": "/usr/local/data/spacy-models/2.3.0/en_core_web_lg",
             "title": "English (Large)",
         },
         "is_docs_run": {
@@ -528,7 +528,7 @@ def req_mock_auth_broker():
                 {"url": "prodigyteams/", "name": "prodigyteams", "uploaded": True},
             ],
         )
-        m.post(f"{broker_address}/api/v1/models/upload")
+        m.post(f"{broker_address}/api/v1/packages/upload")
         m.get(
             f"{broker_address}/api/v1/packages/prodigy/",
             json=[
